@@ -1,7 +1,7 @@
-/* $Id: control.cc 738 2010-09-02 07:21:40Z dreibh $
+/* $Id: control.cc 888 2011-01-21 08:52:19Z dreibh $
  *
  * Network Performance Meter
- * Copyright (C) 2009-2010 by Thomas Dreibholz
+ * Copyright (C) 2009-2011 by Thomas Dreibholz
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -154,11 +154,12 @@ bool performNetPerfMeterAddFlow(MessageReader* messageReader,
    NetPerfMeterAddFlowMessage* addFlowMsg = (NetPerfMeterAddFlowMessage*)&addFlowMsgBuffer;
    addFlowMsg->Header.Type   = NETPERFMETER_ADD_FLOW;
    addFlowMsg->Header.Flags  = 0x00;
-   if(flow->getTrafficSpec().UseCMT) {
-      addFlowMsg->Header.Flags |= NPMAF_USE_CMT;
+   addFlowMsg->CCID          = flow->getTrafficSpec().CCID;
+   if(flow->getTrafficSpec().CMT > 0) {
+      addFlowMsg->Header.Flags |= NPMAF_USE_CMT;   /* Backward compatibility */
    }
-   if(flow->getTrafficSpec().UseRP) {
-      addFlowMsg->Header.Flags |= NPMAF_USE_RP;
+   if(flow->getTrafficSpec().CCID > 0) {
+      addFlowMsg->Header.Flags |= NPMAF_USE_RP;    /* Backward compatibility */
    }
 
    addFlowMsg->Header.Length = htons(addFlowMsgSize);
@@ -182,7 +183,6 @@ bool performNetPerfMeterAddFlow(MessageReader* messageReader,
       htonl((uint32_t)flow->getTrafficSpec().RetransmissionTrials |
             (uint32_t)(flow->getTrafficSpec().RetransmissionTrialsInMS ? NPMAF_RTX_TRIALS_IN_MILLISECONDS : 0));
 
-   addFlowMsg->Padding       = 0x0000;
    addFlowMsg->OnOffEvents   = htons(flow->getTrafficSpec().OnOffEvents.size());
    size_t i = 0;
    for(std::set<unsigned int>::iterator iterator = flow->getTrafficSpec().OnOffEvents.begin();
@@ -753,8 +753,17 @@ static bool handleNetPerfMeterAddFlow(MessageReader*                    messageR
       for(size_t i = 0;i < startStopEvents;i++) {
          trafficSpec.OnOffEvents.insert(ntohl(addFlowMsg->OnOffEvent[i]));
       }
-      trafficSpec.UseCMT = (addFlowMsg->Header.Flags & NPMAF_USE_CMT)    ? true : false;
-      trafficSpec.UseRP  = (addFlowMsg->Header.Flags & NPMAF_USE_RP)     ? true : false;
+      trafficSpec.CMT  = addFlowMsg->CMT;
+      trafficSpec.CCID = addFlowMsg->CCID;
+
+      if(trafficSpec.CMT == 0x00) {   /* Backward compatibility */
+         if(addFlowMsg->Header.Flags & (NPMAF_USE_CMT|NPMAF_USE_RP)) {
+            trafficSpec.CMT = NPAF_CMTRP;
+         }
+         else if(addFlowMsg->Header.Flags & NPMAF_USE_CMT) {
+            trafficSpec.CMT = NPAF_CMT;
+         }
+      }
 
       Flow* flow = new Flow(ntoh64(addFlowMsg->MeasurementID), ntohl(addFlowMsg->FlowID),
                             ntohs(addFlowMsg->StreamID), trafficSpec,
@@ -1048,19 +1057,7 @@ void handleNetPerfMeterIdentify(const NetPerfMeterIdentifyMessage* identifyMsg,
                                                         controlSocketDescriptor,
                                                         controlAssocID);
    if((controlAssocID != 0) && (flow != NULL)) {
-      bool success    = true;
-      int  bufferSize = flow->getTrafficSpec().RcvBufferSize;
-      if(ext_setsockopt(sd, SOL_SOCKET, SO_RCVBUF, &bufferSize, sizeof(bufferSize)) < 0) {
-         std::cerr << "ERROR: Failed to configure receive buffer size on SCTP socket (SO_RCVBUF option) - "
-                   << strerror(errno) << "!" << std::endl;
-         success = false;
-      }
-      bufferSize = flow->getTrafficSpec().SndBufferSize;
-      if(ext_setsockopt(sd, SOL_SOCKET, SO_SNDBUF, &bufferSize, sizeof(bufferSize)) < 0) {
-         std::cerr << "ERROR: Failed to configure send buffer size on SCTP socket (SO_SNDBUF option) - "
-                   << strerror(errno) << "!" << std::endl;
-         success = false;
-      }
+      const bool success = flow->configureSocket(sd);
       sendNetPerfMeterAcknowledge(controlSocketDescriptor, controlAssocID,
                                   ntoh64(identifyMsg->MeasurementID),
                                   ntohl(identifyMsg->FlowID),
