@@ -1,7 +1,7 @@
-/* $Id: flow.cc 791 2010-11-17 09:34:38Z dreibh $
+/* $Id: flow.cc 939 2011-01-28 12:03:50Z dreibh $
  *
  * Network Performance Meter
- * Copyright (C) 2009-2010 by Thomas Dreibholz
+ * Copyright (C) 2009-2011 by Thomas Dreibholz
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,6 +23,7 @@
 #include "control.h"
 #include "transfer.h"
 
+#include <string.h>
 #include <signal.h>
 #include <poll.h>
 #include <assert.h>
@@ -1196,3 +1197,62 @@ void Flow::run()
       }
    } while( (result == true) && (!isStopping()) );
 }
+
+
+// ###### Configure socket parameters #######################################
+bool Flow::configureSocket(const int socketDescriptor)
+{
+    int bufferSize = TrafficSpec.RcvBufferSize;
+    if(ext_setsockopt(socketDescriptor, SOL_SOCKET, SO_RCVBUF, &bufferSize, sizeof(bufferSize)) < 0) {
+        std::cerr << "ERROR: Failed to configure receive buffer size on SCTP socket (SO_RCVBUF option) - "
+                  << strerror(errno) << "!" << std::endl;
+        return(false);
+    }
+    bufferSize = TrafficSpec.SndBufferSize;
+    if(ext_setsockopt(socketDescriptor, SOL_SOCKET, SO_SNDBUF, &bufferSize, sizeof(bufferSize)) < 0) {
+        std::cerr << "ERROR: Failed to configure send buffer size on SCTP socket (SO_SNDBUF option) - "
+                  << strerror(errno) << "!" << std::endl;
+        return(false);
+    }
+
+    if(TrafficSpec.Protocol == IPPROTO_SCTP) {
+#ifdef SCTP_CMT_ON_OFF
+        struct sctp_assoc_value cmtOnOff;
+        cmtOnOff.assoc_id    = 0;
+        cmtOnOff.assoc_value = TrafficSpec.CMT;
+        if(ext_setsockopt(socketDescriptor, IPPROTO_SCTP, SCTP_CMT_ON_OFF, &cmtOnOff, sizeof(cmtOnOff)) < 0) {
+          if(TrafficSpec.CMT != NPAF_PRIMARY_PATH) {
+              std::cerr << "ERROR: Failed to configure CMT usage on SCTP socket (SCTP_CMT_ON_OFF option) - "
+                        << strerror(errno) << "!" << std::endl;
+             return(false);
+          }
+        }
+#else
+        if(TrafficSpec.CMT != NPAF_PRIMARY_PATH) {
+          std::cerr << "ERROR: CMT usage configured, but not supported by this system!" << std::endl;
+          return(false);
+        }
+#endif
+   }
+
+#ifdef HAVE_DCCP
+   if(TrafficSpec.Protocol == IPPROTO_DCCP) {
+      const uint8_t value = TrafficSpec.CCID;
+      if(value != 0) {
+         if(ext_setsockopt(socketDescriptor, SOL_DCCP, DCCP_SOCKOPT_CCID, &value, sizeof(value)) < 0) {
+            std::cerr << "WARNING: Failed to configure CCID #" << (unsigned int)value
+                      << " on DCCP socket (DCCP_SOCKOPT_CCID option) - "
+                      << strerror(errno) << "!" << std::endl;
+            // return(false);
+         }
+      }
+      const uint32_t service[1] = { htonl(SC_NETPERFMETER_DATA) };
+      if(ext_setsockopt(socketDescriptor, SOL_DCCP, DCCP_SOCKOPT_SERVICE, &service, sizeof(service)) < 0) {
+        std::cerr << "ERROR: Failed to configure DCCP service code on DCCP socket (DCCP_SOCKOPT_SERVICE option) - "
+                  << strerror(errno) << "!" << std::endl;
+        return(false);
+      }
+   }
+#endif
+   return(true);
+}
