@@ -1,7 +1,7 @@
-/* $Id: flowtrafficspec.h 728 2010-08-31 08:02:50Z dreibh $
+/* $Id: flowtrafficspec.h 887 2011-01-21 08:35:15Z dreibh $
  *
  * Network Performance Meter
- * Copyright (C) 2009-2010 by Thomas Dreibholz
+ * Copyright (C) 2009-2011 by Thomas Dreibholz
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -71,8 +71,9 @@ class FlowTrafficSpec
    uint8_t                InboundFrameRateRng;
    uint8_t                InboundFrameSizeRng;
 
-   bool                   UseCMT;
-   bool                   UseRP;
+   uint8_t                CMT;
+   uint8_t                CCID;
+
    bool                   ErrorOnAbort;
 };
 
